/**
  This program is free software: you can redistribute it and / or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see < https : //www.gnu.org/licenses/>.
**/


/* Includes ----------------------------------------------------------------- */
#include <Servo.h>

/* Defines ------------------------------------------------------------------ */
#define right_servo_pin 5
#define left_servo_pin  6
#define right_led       7
#define left_led        8
#define min_pulse       1300
#define max_pulse       1700
#define standstill      1500

/* Global variables --------------------------------------------------------- */
Servo g_left_wheel;
Servo g_right_wheel;

/* Private functions ---------------------------------------------------------------- */
void setWheels(int delay_left = 1500, int delay_right = 1500) {
  g_left_wheel.writeMicroseconds(delay_left);
  g_right_wheel.writeMicroseconds(delay_right);
}

void setLed(byte value_left = LOW, byte value_right = LOW) {
  digitalWrite(right_led, value_right);
  digitalWrite(left_led, value_left);
}

/* Arduino functions ---------------------------------------------------------------- */
void setup() {

  /* Attach servos to digital pins defined earlier */
  g_left_wheel.attach(left_servo_pin, min_pulse, max_pulse );
  g_right_wheel.attach(right_servo_pin, min_pulse, max_pulse);

  /* Wait to make sure servos were attached */
  delay(10);

  /* Set servos to standstill movement... */
  g_left_wheel.writeMicroseconds(standstill);
  g_right_wheel.writeMicroseconds(standstill);

  /* or call the setWheels(); function */
  //setWheels();
}

/* Infinite loop */
void loop() {
  /* Move forward, wait, then move backwards */
  setLed(HIGH, HIGH);
  setWheels(1600, 1400);
  delay(1000);
  setWheels();
  setLed(LOW, LOW);
  delay(1000);
  setLed(HIGH, HIGH);
  setWheels(1400, 1600);
  delay(1000);
  setWheels();
  setLed(LOW, LOW);
  delay(1000);


}
